{% extends "base.html" %} {% block main %}

## Examples

Each example offers links to the different renderers / platforms on which it is available. For instance, the hello static example is available for web, local, and static. The web examples will open in a browser-based editor where they can also be executed while others will link to code snippets.

### Basics

A first hello world example available for all three renderers.
Web Local Static
A hello world example with minimumn interactivity.
Web Local
The hello world example from the homepage.
Web Local
Basics of styling and colors.
Web Local Static
Saving (pushing) and loading (popping) styles.
Web Local Static

### Data

Rendering a simple bar chart from a CSV file.
Web Local Static
Drawing a simple bar chart from a JSON file.
Web Local Static
Generating a CSV file from a sketch.
Web Local Static
Generating a JSON file from a sketch.
Web Local Static

### Geo

Drawing with map panning and zooming.
Web Local Static
Drawing a polygon defined by latitude and longitude points.
Web Local Static
Displaying GeoJSON on a map.
Web Local Static

### Images

Drawing an image into a sketch.
Web Local Static
Writing a sketch to an image file.
Web Local Static

### Inputs

Example of taking keyboard input.
Web Local
Example of taking mouse input.
Web Local

### Shapes

Drawing lines.
Web Local Static
Drawing rectangles and squares.
Web Local Static
Drawing ellipses and circles.
Web Local Static
Drawing arcs.
Web Local Static
Drawing complex shapes with lines.
Web Local Static
Drawing complex shapes with bezier curves.
Web Local Static

### Transformations

Moving the origin by translating.
Web Local Static
Zooming in and out by scaling.
Web Local Static
Rotating around the origin.
Web Local Static
Combining multiple transforms together.
Web Local Static
Saving (pushing) and loading (popping) transforms.
Web Local Static
{% endblock %}